# vgetpupil
Installation requirements
----------
Python 3.6
---------
This program is only working with the python version 3.6 because the pupil detectors libraries can only be installed with python 3.6.
If you are using Macports,
`sudo port install python36` and `port select --set python  python36`.

If you are using conda,
`conda install anaconda` and `conda install python=3.6`.

Install and upgrade opencv-python
---------------------------------------------------------
Please run `pip install opencv-python --upgrade`.

Install `vgetpupil`
------------------------
After setting python version to 3.6 and upgrading opencv-python, please run
`pip install vgetpupil`
    
